@@ -1,14 +1,10 @@
 package Filter::Util::Exec ;
 
-require 5.002 ;
-require DynaLoader;
-use strict;
-use warnings;
-use vars qw(@ISA $VERSION) ;
-@ISA = qw(DynaLoader);
-$VERSION = "1.49" ;
+require 5.006 ;
+require XSLoader;
+our $VERSION = "1.58" ;
 
-bootstrap Filter::Util::Exec ;
+XSLoader::load('Filter::Util::Exec');
 1 ;
 __END__
 
@@ -28,6 +24,8 @@ Filters> which use a Unix coprocess.
 See L<Filter::exec>, L<Filter::cpp> and L<Filter::sh> for examples of
 the use of this module.
 
+Note that the size of the buffers is limited to 32-bit.
+
 =head2 B<filter_add()>
 
 The function, C<filter_add> installs a filter. It takes one
